#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-file-cgi
version:              3.1.11
visibility:           public
id:                   wai-app-file-cgi-3.1.11-BgrQQcZJNdm9l62sUmwW4A
key:                  wai-app-file-cgi-3.1.11-BgrQQcZJNdm9l62sUmwW4A
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  d3cf8531c639c3c8ebcadf3743579a18
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.11-BgrQQcZJNdm9l62sUmwW4A
depends:
    array-0.5.6.0 attoparsec-0.14.4-GluE1clWXeWeSjHE1bFts base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Eh88MLcrDxqA6puekTfvJo
    conduit-1.3.6.1-Gg75eynaCMwB90JVBZUVUV
    conduit-extra-1.3.8-2mEPFUvHOvWyogBEVe4VR containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    filepath-1.4.300.1 http-client-0.7.19-D5RaBo9PU4s8YuYDXFr2cz
    http-conduit-2.3.9.1-7PV9PoY806LKEidsz6qgxy
    http-date-0.0.11-2uVoeCzqxaUHiMsHwZNxSx
    http-types-0.12.4-1k09WZUFwaNKy3YYy34Hwy
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN
    network-3.1.4.0-Lt0aE8CPrcjIQCbzsjcySE process-1.6.19.0
    sockaddr-0.0.1-DiUtL6KUhKu6UtbVtXRr2g
    static-hash-0.0.2-L7vrfXyvQPkF24nmIs4fEs text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0 wai-3.2.4-Lrxlo0kYTiqA2TBLB2W4tv
    wai-conduit-3.0.0.4-7TLbOArqgx05DqFFj6xMoJ
    warp-3.4.0-DdJTaI7MJKm2GAnsLaCQWD
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

